# -*- coding: utf-8 -*-


class PayoutStatus:
    """
    Статус выплаты.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PENDING = 'pending'
    """Только для выплат на банковские карты: выплата создана и ожидает подтверждения от эмитента, что деньги можно перевести на указанную банковскую карту."""
    SUCCEEDED = 'succeeded'
    """Выплата успешно завершена, оплата переведена на платежное средство продавца (финальный и неизменяемый статус)."""
    CANCELED = 'canceled'
    """Выплата отменена, инициатор и причина отмены указаны в объекте cancellation_details (финальный и неизменяемый статус)."""
