# -*- coding: utf-8 -*-

class PaymentOrderType:
    """
    Константы, представляющие значения payment_order_type. Возможные значения:

    * utilities - Оплата ЖКУ
    """  # noqa: E501

    """
    Список допустимых значений
    """
    UTILITIES = 'utilities'
    """Оплата ЖКУ"""
