# -*- coding: utf-8 -*-

class StatementType:
    """
    Константы, представляющие значения statement_type. Возможные значения:

    * payment_overview - Квитанция по платежу
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PAYMENT_OVERVIEW = 'payment_overview'
    """Квитанция по платежу"""
