# -*- coding: utf-8 -*-

class DeliveryMethodType:
    """
    Константы, представляющие значения delivery_method_type. Возможные значения:

    * email - На электронную почту
    """  # noqa: E501

    """
    Список допустимых значений
    """
    EMAIL = 'email'
    """На электронную почту"""
